@@ -279,7 +279,15 @@ void MainWindow::restoreOpenSessions()
 
 KUrl MainWindow::getInputUrl()
 {
-    return KUrl(m_protocolInput->currentText() + "://" + m_addressInput->text());
+    QString userInput = m_addressInput->text();
+
+    // percent encode usernames so KUrl can parse it
+    int lastAtIndex = userInput.indexOf(QRegExp("@[^@]+$"));
+    if (lastAtIndex >0) {
+        userInput = KUrl::toPercentEncoding(userInput.left(lastAtIndex)) + userInput.mid(lastAtIndex);
+    }
+
+    return KUrl(m_protocolInput->currentText() + "://" + userInput);
 }
 
 void MainWindow::newConnection(const KUrl &newUrl, bool switchFullscreenWhenConnected, const QString &tabName)
@@ -1118,12 +1126,11 @@ QWidget* MainWindow::newConnectionWidget()
         m_newConnectionTableView->verticalHeader()->setDefaultSectionSize(
             m_newConnectionTableView->fontMetrics().height() + 3);
         m_newConnectionTableView->horizontalHeader()->setStretchLastSection(true);
-        m_newConnectionTableView->horizontalHeader()->setResizeMode(QHeaderView::ResizeToContents);
-        m_newConnectionTableView->resizeColumnsToContents();
         m_newConnectionTableView->setAlternatingRowColors(true);
         // set up sorting and actions (double click open, right click custom menu)
         m_newConnectionTableView->setSortingEnabled(true);
         m_newConnectionTableView->sortByColumn(Settings::connectionListSortColumn(), Qt::SortOrder(Settings::connectionListSortOrder()));
+        m_newConnectionTableView->resizeColumnsToContents();
         connect(m_newConnectionTableView->horizontalHeader(), SIGNAL(sortIndicatorChanged(int,Qt::SortOrder)),
                 SLOT(saveConnectionListSort(int,Qt::SortOrder)));
         connect(m_newConnectionTableView, SIGNAL(doubleClicked(QModelIndex)),
